import React from 'react'
import { get } from 'lodash'
import { withProps } from 'recompose'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { DateParser } from '@pubsweet/ui'

import { Label, Item, Row, Text } from './'

const submittingAuthor = authors => {
  const thisAuthor = authors.filter(e => e.isSubmitting)
  return thisAuthor[0]
}

const AuthorReply = ({ reply, authorName, submittedOn }) => (
  <Root>
    <Row justify="space-between" mb={2}>
      <Item justify="flex-end">
        <Row mb={1}>
          <Item vertical>
            <Label mb={1 / 2}>Author Reply</Label>
            <Text>{reply}</Text>
          </Item>
        </Row>
        <Text ml={1} mr={1} whiteSpace="nowrap">
          {authorName}
        </Text>
        <DateParser timestamp={submittedOn}>
          {date => <Text>{date}</Text>}
        </DateParser>
      </Item>
    </Row>
  </Root>
)

export default withProps(({ fragment: { authors, submitted } }) => ({
  submittedOn: submitted,
  authorName: `${get(submittingAuthor(authors), 'firstName', '')} ${get(
    submittingAuthor(authors),
    'lastName',
    '',
  )}`,
}))(AuthorReply)

// #region styles
const Root = styled.div`
  background-color: ${th('colorBackgroundHue')};
  border: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBackgroundHue3')};
  border-radius: ${th('borderRadius')};
  padding: calc(${th('gridUnit')} * 2);
  margin: ${th('gridUnit')};
`
// #endregion
